@@ -9,11 +9,14 @@ from django.utils.decorators import method_decorator
 
 from sparrow_cloud.access_control.access_verify import access_verify
 from sparrow_cloud.utils.get_settings_value import get_settings_value, get_service_name
+from sparrow_cloud.auth.user_id_authentication import UserIDAuthentication
+
 
 logger = logging.getLogger(__name__)
+auth_user = UserIDAuthentication()
 
-DETAIL_403 = {"message": "无权限访问。"}
-DETAIL_401 = {"message": "身份认证信息未提供。"}
+DETAIL_403 = {"message": "无权限访问。", "code":233403}
+DETAIL_401 = {"message": "身份认证信息未提供。","code":233401}
 
 
 def access_control_fbv(resource=None):
@@ -28,11 +31,12 @@ def access_control_fbv(resource=None):
         def wrap(request, *args, **kwargs):
             skip_access_control = getattr(settings, "SC_SKIP_ACCESS_CONTROL", False)
             if skip_access_control is False or skip_access_control == 'False':
-                user_id = request.META["REMOTE_USER"]
-                if user_id is None:
+                user_auth_tuple = auth_user.authenticate(request)
+                if not user_auth_tuple:
                     return HttpResponse(json.dumps(DETAIL_401), content_type='application/json; charset=utf-8', status=401)
+                user, auth = user_auth_tuple
                 app_name = get_service_name()
-                if not access_verify(user_id=user_id, app_name=app_name, resource_code=resource):
+                if not access_verify(user_id=user.id, app_name=app_name, resource_code=resource):
                     return HttpResponse(json.dumps(DETAIL_403), content_type='application/json; charset=utf-8', status=403)
                 return func(request, *args, **kwargs)
             return func(request, *args, **kwargs)
@@ -52,11 +56,12 @@ def access_control_cbv_all(resource=None):
             def wrap(request, *args, **kwargs):
                 skip_access_control = getattr(settings, "SC_SKIP_ACCESS_CONTROL", False)
                 if skip_access_control is False or skip_access_control == 'False':
-                    user_id = request.META["REMOTE_USER"]
-                    if user_id is None:
+                    user_auth_tuple = auth_user.authenticate(request)
+                    if not user_auth_tuple:
                         return HttpResponse(json.dumps(DETAIL_401), content_type='application/json; charset=utf-8', status=401)
+                    user, auth = user_auth_tuple
                     app_name = get_service_name()
-                    if not access_verify(user_id=user_id, app_name=app_name, resource_code=resource):
+                    if not access_verify(user_id=user.id, app_name=app_name, resource_code=resource):
                         return HttpResponse(json.dumps(DETAIL_403), content_type='application/json; charset=utf-8', status=403)
                     return function(request, *args, **kwargs)
                 return function(request, *args, **kwargs)
@@ -81,13 +86,14 @@ def access_control_cbv_method(resource):
             def wrap(request, *args, **kwargs):
                 skip_access_control = getattr(settings, "SC_SKIP_ACCESS_CONTROL", False)
                 if skip_access_control is False or skip_access_control == 'False':
-                    user_id = request.META["REMOTE_USER"]
+                    user_auth_tuple = auth_user.authenticate(request)
                     app_name = get_service_name()
                     resource_code = (dict((k.lower(), v) for k, v in resource.items())).get(request.method.lower())
                     if resource_code:
-                        if user_id is None:
+                        if not user_auth_tuple:
                             return HttpResponse(json.dumps(DETAIL_401), content_type='application/json; charset=utf-8', status=401)
-                        if not access_verify(user_id=user_id, app_name=app_name, resource_code=resource_code):
+                        user, auth = user_auth_tuple
+                        if not access_verify(user_id=user.id, app_name=app_name, resource_code=resource_code):
                             return HttpResponse(json.dumps(DETAIL_403), content_type='application/json; charset=utf-8', status=403)
                     return function(request, *args, **kwargs)
                 return function(request, *args, **kwargs)
